@@ -162,19 +162,19 @@ according to the way OAuth Core spec defines.
 sub normalize_params {
     my $params = shift;
     my @pairs = ();
-    for my $k (keys %$params) {
+    for my $k (sort keys %$params) {
         if (!ref $params->{$k}) {
             push @pairs, 
                 sprintf(q{%s=%s}, encode_param($k), encode_param($params->{$k}));
         }
         elsif (ref $params->{$k} eq 'ARRAY') {
-            for my $v (@{ $params->{$k} }) {
+            for my $v (sort @{ $params->{$k} }) {
                 push @pairs, 
                     sprintf(q{%s=%s}, encode_param($k), encode_param($v));
             }
         }
     }
-    return join('&', sort { $a cmp $b } @pairs);
+    return join('&', @pairs);
 }
 
 =head2 parse_auth_header($header)
